@@ -1,4 +1,5 @@
 import json
+import sys
 import time
 import base64
 import asyncio
@@ -18,6 +19,7 @@ async def _get_client(ls: int):
     TonlibClient.enable_unaudited_binaries()
     client = TonlibClient(ls_index=ls, verbosity_level=1)
     await client.init_tonlib()
+    client.tonlib_wrapper.__del__()
     return client
 
 
@@ -71,8 +73,9 @@ def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibCl
         try:
             asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
         except:
-            close_client(client)
             raise ton.tonlibjson.TonlibException
+        finally:
+            close_client(client)
 
         print('DONE')
     if len(nft_items) < len(addresses):
@@ -82,8 +85,8 @@ def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibCl
 
 async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict = None, ls=0):
     if not client.tonlib_wrapper._is_working:
-        close_client(client)
-        client = get_client(ls)
+        await client.tonlib_wrapper.close()
+        client = await _get_client(ls)
     account = await client.find_account(addr, preload_state=False)
     x = await account.get_nft_data()
     collection_address = x['collection_address'].to_string()
